@@ -3,7 +3,7 @@ from django.contrib.auth.forms import AuthenticationForm, UserCreationForm
 
 register = template.Library()
 
-@register.inclusion_tag('registration/partial/login.html')
+@register.inclusion_tag('user/partial/sign_in.html')
 def sign_in_form():
     return {'form': AuthenticationForm()}
     
